@@ -18,7 +18,7 @@ GType goa_identity_sign_in_flags_get_type (void) G_GNUC_CONST;
 GType goa_identity_query_mode_get_type (void) G_GNUC_CONST;
 #define GOA_TYPE_IDENTITY_QUERY_MODE (goa_identity_query_mode_get_type ())
 
-/* enumerations from "goaidentitymanager.h" */
+/* enumerations from "goaidentitymanagererror.h" */
 GType goa_identity_manager_error_get_type (void) G_GNUC_CONST;
 #define GOA_TYPE_IDENTITY_MANAGER_ERROR (goa_identity_manager_error_get_type ())
 
@@ -29,10 +29,6 @@ GType struct_struct_get_type (void) G_GNUC_CONST;
 /* enumerations from "goakerberosidentityinquiry.h" */
 GType goa_kerberos_identity_query_mode_get_type (void) G_GNUC_CONST;
 #define GOA_TYPE_KERBEROS_IDENTITY_QUERY_MODE (goa_kerberos_identity_query_mode_get_type ())
-
-/* enumerations from "um-realm-manager.h" */
-GType um_realm_errors_get_type (void) G_GNUC_CONST;
-#define UM_TYPE_REALM_ERRORS (um_realm_errors_get_type ())
 G_END_DECLS
 
 #endif /* GOA_IDENTITY_ENUM_TYPES_H */
